@@ -154,6 +154,8 @@ class Cliflo(object):
         ### Open headless Chrome driver
         options = webdriver.ChromeOptions()
         options.add_argument("headless")
+        options.add_argument("--disable-dev-shm-using")
+        options.add_argument("--remote-debugging-port=9222")
         driver = webdriver.Chrome(self.chromedriver, options=options)
 
         ### Open main Cliflo site as a public login
@@ -239,6 +241,8 @@ class Cliflo(object):
 
         options = webdriver.ChromeOptions()
         options.add_argument("headless")
+        options.add_argument("--disable-dev-shm-using")
+        options.add_argument("--remote-debugging-port=9222")
         driver = webdriver.Chrome(self.chromedriver, options=options)
 
         ### Open main Cliflo site for login
